==> drupal-expay-8.x-1.2.tar.gz: commerce_expay/src/PluginForm/ExpayForm.php <==
<?php

namespace Drupal\expay\PluginForm;

use Drupal\commerce_payment\Entity\PaymentInterface;
use Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayInterface;
use Drupal\commerce_payment_example\PluginForm\OffsiteRedirect\PaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

class ExpayForm extends PaymentOffsiteForm {
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    /** @var PaymentInterface $payment */
    $payment = $this->entity;
    $order_id = $payment->getOrderId();
    $payment->setRemoteId($order_id)->save();

    /** @var OffsitePaymentGatewayInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();

    $data = [
      'key' => EXPAY_PUBLIC_KEY,
      'amount' => sprintf('%.2f', $payment->getAmount()->getNumber()),
      'order' => sprintf("%d", $payment->getRemoteId()),
      'language' => 'en',
      'env' => $payment_gateway_plugin->getMode() === 'test' ? 'dev': 'live',
      'successUrl' => Url::fromUri($form['#return_url'])->toString(),
      'rejectUrl'  => Url::fromUri($form['#cancel_url'])->toString(),
      'waitingUrl' => Url::fromUri($form['#return_url'])->toString(),
      'forceRedirect' => 'true',
    ];

    $url = 'https://api' . ($payment_gateway_plugin->getMode() === 'test' ? '.sandbox': '') . '.expay.asia/merchant/light/#/?' . http_build_query($data);

    $form['frame'] = [
      'example one' => [
        '#type' => 'inline_template',
        '#template' => '<iframe class="col-md-12" height="700" frameborder="0" allowtransparency="true" name="iframe_expay" id="iframe_expay" src="{{ url }}"></iframe><style>
#ZXrHzIujvBKC {
display: none;
margin-bottom: 30px;
padding: 20px 10px;
background: #D30000;
text-align: center;
font-weight: bold;
color: #fff;
border-radius: 5px;
}

.adBanner {
    background-color: transparent;
    height: 1px;
    width: 1px;
}
</style>

<div id="ZXrHzIujvBKC">
  To proceed with checkout you should disable your ad blocker and refresh the page.
</div>

<div id="wrapfabtest">
    <div class="adBanner">
    </div>
</div>',
        '#context' => [
          'url' => $url,
        ],
      ],
    ];

    $form['actions']['cancel'] = [
      '#type' => 'link',
      '#title' => $this->t('Cancel'),
      '#url' => Url::fromUri($form['#cancel_url']),
    ];
    $form['#attached']['library'][] = 'expay/payment_options';

    return $form;
  }
}

==> drupal-expay-8.x-1.6.tar.gz: commerce_expay/src/PluginForm/ExpayForm.php <==
<?php

namespace Drupal\expay\PluginForm;

use Drupal\commerce_payment\Entity\PaymentInterface;
use Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayInterface;
use Drupal\commerce_payment_example\PluginForm\OffsiteRedirect\PaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

class ExpayForm extends PaymentOffsiteForm {
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    /** @var PaymentInterface $payment */
    $payment = $this->entity;
    $order_id = $payment->getOrderId();
    $payment->setRemoteId($order_id)->save();

    /** @var OffsitePaymentGatewayInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();

    $data = [
      'key' => PS_PUBLIC_KEY,
      'amount' => sprintf('%.2f', $payment->getAmount()->getNumber()),
      'order' => sprintf("%d", $payment->getRemoteId()),
      'language' => 'en',
      'successUrl' => Url::fromUri($form['#return_url'])->toString(),
      'rejectUrl'  => Url::fromUri($form['#cancel_url'])->toString(),
      'waitingUrl' => Url::fromUri($form['#return_url'])->toString(),
      'forceRedirect' => 'true',
    ];


    $url = ($payment_gateway_plugin->getMode() === 'test' ? PS_SANDBOX_LINK : PS_LIVE_LINK) . '/light/#/?' . http_build_query($data);

    $form['frame'] = [
      'example one' => [
        '#type' => 'inline_template',
        '#template' => '<iframe class="col-md-12" height="700" frameborder="0" allowtransparency="true" name="iframe_payserver" id="iframe_payserver" src="{{ url }}"></iframe><style>
#ZXrHzIujvBKC {
display: none;
margin-bottom: 30px;
padding: 20px 10px;
background: #D30000;
text-align: center;
font-weight: bold;
color: #fff;
border-radius: 5px;
}

.adBanner {
    background-color: transparent;
    height: 1px;
    width: 1px;
}
</style>

<div id="ZXrHzIujvBKC">
  To proceed with checkout you should disable your ad blocker and refresh the page.
</div>

<div id="wrapfabtest">
    <div class="adBanner">
    </div>
</div>',
        '#context' => [
          'url' => $url,
        ],
      ],
    ];

    $form['actions']['cancel'] = [
      '#type' => 'link',
      '#title' => $this->t('Cancel'),
      '#url' => Url::fromUri($form['#cancel_url']),
    ];
    $form['#attached']['library'][] = 'expay/payment_options';

    return $form;
  }
}
